@@ -41,7 +41,7 @@ shinyServer(function(input, output, session) {
       if ( input$exporthtml != 0 ) {
         setwd(outputDir)
         fn <- paste("tab-",format(Sys.time(),"%Y%m%d-%H%M%S"), sep="")
-        m <- plotSparkTable(data()$sparkO,outputType="html",filename=fn,graphNames="spark")
+        m <- export(data()$sparkO,outputType="html",filename=fn,graphNames="spark")
         cat("--> exported to",outputDir,"\n")
         flush.console()
         setwd(tempdir)
@@ -56,7 +56,7 @@ shinyServer(function(input, output, session) {
       if ( input$exportlatex != 0 ) {
         setwd(outputDir)
         fn <- paste("tab-",format(Sys.time(),"%Y%m%d-%H%M%S"), sep="")
-        m <- plotSparkTable(data()$sparkO,outputType="tex",filename=fn,graphNames="spark")
+        m <- export(data()$sparkO,outputType="tex",filename=fn,graphNames="spark")
 
         if ( Sys.which("pdflatex") != "" ) {
           texi2dvi(file=paste(fn,".tex",sep=""), pdf=TRUE, clean=TRUE, quiet=TRUE)
@@ -202,12 +202,12 @@ shinyServer(function(input, output, session) {
 
   output$cgroups <- renderUI({
     if ( is.null(input$groups) ) {
-      sel <- data()$groups
+      sel <- as.character(data()$groups)
     } else {
-      sel <- input$groups
+      sel <- as.character(input$groups)
     }
-    sel <- which(sel%in%data()$groups)
-    checkboxGroupInput("groups", label=h3("Select groups"), choices=data()$groups, selected=sel)
+    sel <- sel[which(sel%in%data()$groups)]
+    checkboxGroupInput("groups", label=h3("Select groups"), choices=as.character(data()$groups), selected=sel)
   })
 
   output$origdata = renderDataTable({
@@ -397,7 +397,18 @@ shinyServer(function(input, output, session) {
 
   output$sparkplot = renderDataTable({
     setwd(paste(tempdir,"/www",sep=""))
-    m <- plotSparkTable(data()$sparkO,outputType="html",filename=NULL,graphNames="out")
+    cat("\n###################\n")
+    tmpfile <- tempfile()
+    tmpdat <- data()$sparkO
+    save(tmpdat, file=tmpfile)
+    fn <- paste("tab-",format(Sys.time(),"%Y%m%d-%H%M%S"), sep="")
+    cat("the required data and R-code to re-generate the current graphical table is:\n")
+    cat(paste0("# load('",paste(unlist(strsplit(tmpfile, "\\\\")), collapse="\\\\"),"')\n"))
+    cat(paste0("# export(tmpdat, outputType='html', filename='",fn,"', graphNames='spark') # html\n"))
+    cat(paste0("# export(tmpdat, outputType='tex', filename='",fn,"', graphNames='spark') # tex\n"))
+    cat("###################\n")
+    flush.console()
+    m <- export(data()$sparkO,outputType="html",filename=NULL,graphNames="out")
     setwd("../")
     cbind(rownames(m),m)
   })
